@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem
+from netbox_storage.models import Filesystem, Drive
 
 
 #
@@ -16,3 +16,13 @@ class NestedFilesystemSerializer(WritableNestedSerializer):
     class Meta:
         model = Filesystem
         fields = ["id", "url", "display", "filesystem"]
+
+
+class NestedDriveSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:drive-detail"
+    )
+
+    class Meta:
+        model = Drive
+        fields = ["id", "url", "display", "size", "identifier"]
