@@ -14,12 +14,15 @@ class LinuxVolumeBaseTable(NetBoxTable):
 
     fs = tables.Column(
         linkify=True,
+        verbose_name="Filesystem"
     )
     vg_name = tables.Column(
         linkify=True,
+        verbose_name="Volume Group Name"
     )
     lv_name = tables.Column(
         linkify=True,
+        verbose_name="Logical Volume Name"
     )
 
 
